.. luminadb documentation master file, created by
   sphinx-quickstart on Sat Jul 26 19:21:12 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

LuminaDB Documentation
=============================

.. toctree::
    :maxdepth: 12

    :caption: LuminaDB

    SimpleGuide
    ModelAPI
    DatabaseModes


API Documentation
=============================

.. toctree::
    :maxdepth: 1

    :caption: API Documentation

    api_reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

